#
# spec file for package libqt5-qtdeclarative
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define qt5_snapshot 0

%define libname libQtQuick5

Name:           libqt5-qtdeclarative
Version:        5.12.7
Release:        4.2.1
Summary:        Qt 5 Declarative Library
License:        LGPL-2.1-with-Qt-Company-Qt-exception-1.1 or LGPL-3.0-only
Group:          Development/Libraries/X11
Url:            https://www.qt.io
%define base_name libqt5
%define real_version 5.12.7
%define so_version 5.12.7
%define tar_version qtdeclarative-everywhere-src-5.12.7
Source:         https://download.qt.io/official_releases/qt/5.12/%{real_version}/submodules/%{tar_version}.tar.xz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM https://codereview.qt-project.org/c/qt/qtdeclarative/+/299258/1
Patch1:         fix-subpixel-positioned-text.patch
# PATCH-FIX-OPENSUSE sse2_nojit.patch -- enable JIT and sse2 only on sse2 case
Patch100:       sse2_nojit.patch
# PATCH-FIX-OPENSUSE Switch to use python3 at build time
Patch102:       qtdeclarative-switch-to-python3.patch
BuildRequires:  fdupes
BuildRequires:  libQt5Core-private-headers-devel >= %{version}
BuildRequires:  libQt5Gui-private-headers-devel >= %{version}
BuildRequires:  libQt5Test-private-headers-devel >= %{version}
BuildRequires:  libQt5Widgets-private-headers-devel >= %{version}
BuildRequires:  python3-base
BuildRequires:  pkgconfig(Qt5Core) >= %{version}
BuildRequires:  pkgconfig(Qt5Gui) >= %{version}
BuildRequires:  pkgconfig(Qt5Network) >= %{version}
BuildRequires:  pkgconfig(Qt5Sql) >= %{version}
BuildRequires:  pkgconfig(Qt5Widgets) >= %{version}
%if %qt5_snapshot
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  xz
# NOTE recheck this once/if this package gets further splitted
%requires_ge libQt5Core5
%requires_ge libQt5Gui5
%requires_ge libQt5Network5
%requires_ge libQt5Sql5
%requires_ge libQt5Test5
%requires_ge libQt5Widgets5

%description
Qt is a set of libraries for developing applications.

This package contains base tools, like string, xml, and network
handling.

%prep
%autosetup -p1 -n %{tar_version}

%package -n %libname
Summary:        Qt 5 Declarative Library
Group:          Development/Libraries/X11

%description -n %libname
Qt is a set of libraries for developing applications.

This package contains base tools, like string, xml, and network
handling.

%package devel
Summary:        Qt Development Kit
Group:          Development/Libraries/X11
Requires:       %libname = %{version}
Requires:       %{name}-tools = %{version}
Provides:       libQt5Quick-devel = %{version}
Obsoletes:      libQt5Quick-devel < %{version}

%description devel
You need this package, if you want to compile programs with qtdeclarative.

%package tools
Summary:        Qt 5 Declarative Tools
Group:          Development/Tools/Debuggers

%description tools
Qt is a set of libraries for developing applications.

This package contains aditional tools for inspecting, testing, viewing, etc, QML imports and files.

%package private-headers-devel
Summary:        Non-ABI stable experimental API
Group:          Development/Libraries/C and C++
BuildArch:      noarch
Requires:       %{name}-devel = %{version}
Requires:       libQt5Core-private-headers-devel >= %{version}
Requires:       libQt5Gui-private-headers-devel >= %{version}
Requires:       libQt5Test-private-headers-devel >= %{version}
Requires:       libQt5Widgets-private-headers-devel >= %{version}
Provides:       libQt5Quick-private-headers-devel = %{version}
Obsoletes:      libQt5Quick-private-headers-devel < %{version}

%description private-headers-devel
This package provides private headers of libqt5-qtdeclarative that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package examples
Summary:        Qt5 quick/qml examples
Group:          Development/Libraries/X11
Recommends:     %{name}-devel
Recommends:     %{name}-tools

%description examples
Examples for libqt5-qtdeclarative (quick/qml) modules.

%post -n %libname -p /sbin/ldconfig

%postun -n %libname -p /sbin/ldconfig

%build
%if %qt5_snapshot
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif

mkdir -p %{_target_platform}
pushd %{_target_platform}
qmake-qt5 ..
popd

%{__make} %{?_smp_mflags} VERBOSE=1 -C %{_target_platform}

%ifarch %ix86
%if 0%{?sle_version:%sle_version} < 150000
# build libQt5Qml with no_sse2
mkdir -p %{_target_platform}-no_sse2
pushd %{_target_platform}-no_sse2
%qmake5 -config no_sse2 ..
make sub-src-clean
%{__make} %{?_smp_mflags} VERBOSE=1 -C src/qml
popd
%endif
%endif

%install
pushd %{_target_platform}
%qmake5_install
popd

%ifarch %ix86
%if 0%{?sle_version:%sle_version} < 150000
mkdir -p %{buildroot}%{_libqt5_libdir}//sse2
mv %{buildroot}%{_libqt5_libdir}/libQt5Qml.so.5* %{buildroot}%{_libqt5_libdir}/sse2/
pushd %{_target_platform}-no_sse2/src/qml
%qmake5_install
popd
%endif
%endif

find %{buildroot}/%{_libdir} -type f -name '*la' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} \;
find %{buildroot}/%{_libdir}/pkgconfig -type f -name '*pc' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} \;
# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

# put all the binaries to %%_bindir, add -qt5 suffix, and symlink them back to %%_qt5_bindir
mkdir -p %{buildroot}%{_bindir}
pushd %{buildroot}%{_libqt5_bindir}
for i in * ; do
  case "${i}" in
    qmlplugindump|qmlprofiler)
      mv $i ../../../bin/${i}-qt5
      ln -s ../../../bin/${i}-qt5 .
      ln -s ../../../bin/${i}-qt5 $i
      ;;
   *)
      mv $i ../../../bin/
      ln -s ../../../bin/$i .
      ;;
  esac
done
popd

%fdupes -s %{buildroot}%{_libqt5_includedir}
%fdupes -s %{buildroot}%{_libqt5_examplesdir}

%files -n %libname
%license LICENSE.*
%{_libqt5_libdir}/libQt5Q*.so.*
%ifarch %ix86
%if 0%{?sle_version:%sle_version} < 150000
%{_libqt5_libdir}/sse2/libQt5Q*.so.*
%endif
%endif
%dir %{_libqt5_archdatadir}/qml
%dir %{_libqt5_archdatadir}/qml/Qt
%{_libqt5_archdatadir}/qml/QtQuick
%{_libqt5_archdatadir}/qml/QtQuick.2
%{_libqt5_archdatadir}/qml/QtQml
%{_libqt5_archdatadir}/qml/builtins.qmltypes
%dir %{_libqt5_archdatadir}/qml/Qt/labs
%{_libqt5_archdatadir}/qml/Qt/labs/folderlistmodel/
%{_libqt5_archdatadir}/qml/Qt/labs/settings/
%{_libqt5_archdatadir}/qml/Qt/labs/sharedimage/
%{_libqt5_archdatadir}/qml/Qt/labs/qmlmodels/
%{_libqt5_archdatadir}/qml/Qt/labs/wavefrontmesh/
%{_libqt5_plugindir}/qmltooling

%files private-headers-devel
%license LICENSE.*
%{_libqt5_includedir}/Qt*/%{so_version}

%files tools
%license LICENSE.*
%{_bindir}/*
%{_libqt5_bindir}/*

%files devel
%license LICENSE.*
%exclude %{_libqt5_includedir}/Qt*/%{so_version}
%{_libqt5_includedir}/Qt*
%{_libqt5_libdir}/cmake/Qt5*
%{_libqt5_libdir}/libQt5*.prl
%{_libqt5_libdir}/libQt5Q*.so
%{_libqt5_libdir}/libQt5*.a
%{_libqt5_libdir}/pkgconfig/Qt5Q*.pc
%{_libqt5_archdatadir}/mkspecs/modules/*.pri
%{_libqt5_archdatadir}/mkspecs/features/qmlcache.prf
%{_libqt5_archdatadir}/mkspecs/features/qtquickcompiler.prf
%{_libqt5_archdatadir}/qml/QtTest

%files examples
%license LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Tue May  5 2020 fvogt@suse.com
- Add patch to fix kerning with certain labels (QTBUG-49646):
  * fix-subpixel-positioned-text.patch
* Fri Jan 31 2020 fabian@ritter-vogt.de
- Update to 5.12.7:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.12.7/?h=v5.12.7
* Thu Nov 14 2019 fabian@ritter-vogt.de
- Update to 5.12.6:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.12.6/?h=v5.12.6
* Thu Sep 12 2019 christophe@krop.fr
- Update to 5.12.5:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.12.5/?h=5.12.5
* Fri Jun 14 2019 fabian@ritter-vogt.de
- Update to 5.12.4:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.12.4/?h=5.12.4
- Remove patches, now upstream:
  * Dont-crash-when-accessing-invalid-properties.patch
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Add patch to fix crash (QTBUG-75203):
  * Dont-crash-when-accessing-invalid-properties.patch
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.12.2/?h=5.12.2
* Mon Feb  4 2019 fabian@ritter-vogt.de
- Work around cmake issue by expanding make_jobs manually, ignoring
  cmake breaks autoprovides
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.12.1/?h=v5.12.1
- cmake breaks %%make_jobs - ignore it (boo#1091864)
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.12.0/?h=5.12.0
* Mon Nov 26 2018 fabian@ritter-vogt.de
- Remove unneeded BuildReq on Xml modules (boo#1117316)
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
- New Qt.labs.wavefrontmesh module
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
- Refresh patches:
  * qtdeclarative-switch-to-python3.patch
  * sse2_nojit.patch
- Apply sse2_nojit.patch unconditionally
- Use %%license
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.11.0/?h=v5.11.0
- Includes fix for various issues with the JS/QML Date object
  (boo#1114570, QTBUG-72109, QTBUG-56787)
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
- Remove patches, now upstream
  * revert-delay-deletion-of-qsgtextures.patch
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtdeclarative.git/plain/dist/changes-5.10.1/?h=v5.10.1
* Fri Jan 26 2018 alarrosa@suse.com
- Update patch to also modify some python2-style prints to use python3-style
  * qtdeclarative-switch-to-python3.patch
* Fri Jan 26 2018 mlin@suse.com
- Switch to use python3 at build time
  * qtdeclarative-switch-to-python3.patch
* Fri Dec  8 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtdeclarative.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
- Refresh revert-delay-deletion-of-qsgtextures.patch
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
- Remove patches, now upstream:
  * implicit-type-import-in-modules.patch
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
- Dropped patches, now upstream:
  * rebuild-qqmldata-propertycache-if-deleted.patch
  * support-non-integer-pixel-ratios-qquickwidget.patch
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1:
  * Qt QML
    + Added support for enum declarations in QML.
    + Added support for retranslation.
  * Qt Quick
    + Added a shapes plugin, providing a Shape type under QtQuick.Shapes 1.0. This allows adding stroked and filled paths into Qt Quick scenes. Such
    + Added the Qt.labs.handlers plugin, providing TapHandler, PinchHandler and DragHandler. These are the beginnings of the Pointer Handlers which
    + QQuickItem layers can now request to be backed by multisample framebuffers via the property layer.samples
    + Added font.kerning and font.preferShaping properties for advanced control over the font shaping subsystem.
    + Added advance property to Text to retrieve the typographical advance width.
    + Added Image element support for direct loading of ETC1 and ETC2 compressed textures from .pkm files. (on platforms where ETC1/2 are supported)
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
- Remove patches, now upstream:
  * support-non-integer-pixel-ratios-qquickwidget.patch
  * rebuild-qqmldata-propertycache-if-deleted.patch
- Add patch to fix implicit import of internal types inside modules:
  * implicit-type-import-in-modules.patch
* Wed Aug  9 2017 ro@suse.de
- Don't special case sse2 libs on i586 for SLE-15, it supports
  only SSE2 capable CPUs.
* Mon Jul 24 2017 fabian@ritter-vogt.de
- Add patch to revert upstream commit introducing a massive memory
  leak (QTBUG-62117):
  * revert-delay-deletion-of-qsgtextures.patch
* Mon Jul 17 2017 fabian@ritter-vogt.de
- Add patch to fix crash related to shared QQmlEngine instances
  (QTBUG-61681, kde#381525):
  * rebuild-qqmldata-propertycache-if-deleted.patch
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Fri Jun 23 2017 lbeltrame@kde.org
- Add upstream patch support-non-integer-pixel-ratios-qquickwidget.patch
  * Add support for non-integer scaling to QQuickWidget (QTBUG-61502)
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
- Refresh patches:
  * sse2_nojit.patch
* Fri Apr 28 2017 wbauer@tmo.at
- Add back sse2_nojit.patch to support 32bit CPUs without SSE2
  instructions (boo#1027691)
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
- Drop upstreamed/obsolete patches:
  overflow.patch, qtdeclarative-opensource-src-5.6.0-qml_no-lifetime-dse.patch,
  V4-Always-set-the-tag-when-boxing-a-pointer.patch,
  Add-a-facility-to-version-type-information.patch,
  V4-Free-up-2-address-bits-in-64bit-mode.patch,
  masm-unaligned-stack-pointer.patch and
  fix-crash-on-exit-when-using-default-property-aliases-with-layouts.patch
* Mon Oct 17 2016 lbeltrame@kde.org
- Add fix-crash-on-exit-when-using-default-property-aliases-with-layouts.patch:
  fix Plasma screenlocker crash on unlock (boo#999548, QTBUG#51927)
* Tue Oct 11 2016 schwab@suse.de
- masm-unaligned-stack-pointer.patch: align stack on 16 byte boundaries in
  the YarrJIT (bsc#1003880)
* Wed Sep 28 2016 fabian@ritter-vogt.de
- Add new version of V4-Free-up-2-address-bits-in-64bit-mode.patch
  * Fix testcase failure (boo#989341, QTBUG#54822)
- Only apply patch on AArch64 to avoid regressions where patch not
  needed (it's experimental)
* Mon Sep 26 2016 fvogt@suse.com
- Add upstream patches for aarch64 with VA_BITS=48 (boo#989341, QTBUG#54822)
  * V4-Always-set-the-tag-when-boxing-a-pointer.patch
  * Add-a-facility-to-version-type-information.patch
  * V4-Free-up-2-address-bits-in-64bit-mode.patchv4-set-tag.patch
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
- Axe dead qml_only_release_types_if_they_arent_referenced_anymore.patch
* Tue Jun 21 2016 lbeltrame@kde.org
- Add qtdeclarative-opensource-src-5.6.0-qml_no-lifetime-dse.patch
  * Fix crash with i586 and QML loaders (boo#985768)
* Thu Jun 16 2016 hrvoje.senjan@gmail.com
- Added qml_only_release_types_if_they_arent_referenced_anymore.patch
* Wed Jun  8 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
- Drop upstreamed
  Workaround-for-crashes-in-QtQml-code-relating-to-null-this-pointers.patch
* Thu May 26 2016 hrvoje.senjan@gmail.com
- Added Workaround-for-crashes-in-QtQml-code-relating-to-null-this-pointers.patch
  to prevent issues with GCC 6
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
- Drop support for non-SSE2 machines
- Drop sse2_nojit.patch
- Drop upstreamed patches:
  0001-scene-graph-fixed-memory-leak-in-qsgbatchrenderer-re.patch,
  Refactor-FxViewItem-releasing-code.patch and
  sanitize-visibleItems-list-after-model-insertions.patch
- Add overflow.patch to resolve
  "Statement might be overflowing a buffer" post-build-check error
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
* Sat Feb 13 2016 matz@suse.com
- Add 0001-scene-graph-fixed-memory-leak-in-qsgbatchrenderer-re.patch
  fixing a memory leak, QTBUG#48799.
* Mon Feb  1 2016 hrvoje.senjan@gmail.com
- Added sanitize-visibleItems-list-after-model-insertions.patch
  and Refactor-FxViewItem-releasing-code.patch to help in resolving
  kde#352055 and qtbug#48870
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1 (boo#954149)
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
- Drop avoid-calling-potentially-pure-virtual-method.patch, merged
  upstream
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
* Mon Apr 27 2015 hrvoje.senjan@gmail.com
- Add avoid-calling-potentially-pure-virtual-method.patch, QTBUG#45753
* Sat Apr 25 2015 hrvoje.senjan@gmail.com
- Extend sse2_nojit.patch to warn users without SSE2 extension that
  their processor is officially not supported.
  Also pass -msse2 -mfpmath=sse flags when we are building with SSE2
* Thu Apr  9 2015 hrvoje.senjan@gmail.com
- Adjust usage of latest %%qmake5_install macro
* Tue Feb 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-5-4-1-released/
- Add minimal requires on other Qt5 libs
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 5.4 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-5-4-released/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 5.4 RC
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-5-4-release-candidate-available/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
- Drop patches merged upstream:
  0005-Fix-crash-with-foreach-on-arguments-object.patch
  0004-QML-parse-.js-files-as-JavaScript-not-QML.patch
  0006-Move-syncTimer-measurment-to-the-correct-place.patch
  0003-Fix-crashes-when-calling-Array.sort-with-imperfect-s.patch
  0001-Fix-crash-with-cleanup-of-animators.patch
  0002-Support-padding-in-images-stored-in-atlas-texture.patch
* Mon Sep 22 2014 hrvoje.senjan@gmail.com
- Add sse2_nojit.patch: enable JIT and sse2 only on sse2 case
- Build QtQML module twice on ix86, without and with sse2 (sse2
  library is placed to %%_libdir/sse2/ (bnc#897758)
* Tue Sep 16 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2 final
  * No changes since previous snapshot
  * Use official tars
- Added patches from upstream 5.3 branch:
  0001-Fix-crash-with-cleanup-of-animators.patch (QTBUG#37833),
  0002-Support-padding-in-images-stored-in-atlas-texture.patch,
  0003-Fix-crashes-when-calling-Array.sort-with-imperfect-s.patch
  (QTBUG#39072),
  0004-QML-parse-.js-files-as-JavaScript-not-QML.patch (QTBUG#40143),
  0005-Fix-crash-with-foreach-on-arguments-object.patch (QTBUG#40844)
  and 0006-Move-syncTimer-measurment-to-the-correct-place.patch
  (QTBUG#40556)
* Thu Sep  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2~git20140904 (rd8bc98b):
  * Tip of the bugfix 5.3.2 branch
  * Contains many bugfixes over 5.3.1 release:
  * Doc: Added a link to the QML advanced tutorial
  * Don't use d->instanceModel after free'ing it
  * Fix crash with early QObject property access
  * Fix typo in DelegateModelGroup documentation
  * Protect some members in QQmlObjectCreator
  * Initialize variable
  * Don't abuse new to do a reinterpret_cast
  * Protect incubation against its creator being deleted.
  * Add 5.3.2 changelog for qtdeclarative
  * Fix crash with recursively loading cached compilation units
  * Fix typo in StateChangeScript documentation.
  * Added the QtSQL dependency info. to the project file
  * tst_dialogs: verify that rootObject is valid
  * tst_dialogs: QTRY_ on the expression
    (spyVisibilityChanged.count) not the variable.
  * The cached objects can be deleted, so keep them in a QPointer
  * Fix potential deadlook in threaded renderloop.
  * Added a signal handler
  * Fix typo in Context2D documentation.
  * Disable threaded FBO canvas drawing when not supported.
  * V4 JIT: fix JS stack frame size calculation.
  * Correct strokeRect documentation.
  * Silence harmless compiler warning.
  * benchmarks: Skip compilation of (and mark with FIXME) a few
    benchmarks that don't build.
  * benchmarks/particles: fix projects to actually build
  * Fix compilation of tst_compilation (:-P) benchmark.
  * Avoid double deletion when deleting an incubating component.
  * Invalidate the scenegraph properly in the rendercontrol
  * Fix crash when loading invalid QML with behavior on
    invalid group property
  * Fix crash when animators are deleted just after being started
  * Don't try to reload QQuick images when changing to
    null screen
  * Clarify Component.onCompleted/onDestruction docs
  * Fix fbo creation and resize logic in QQuickWidget
  * Fix Qt.include with cached compilation units and resources
  * Synchronize PathView gesture grabbing with other items.
  * Fix FBO recreated every time the QSG node is updated under
    some conditions
  * More QQuickCanvas cleanup handling.
  * Make canvas cleanup work propertly...
  * Use the current context to resolve extensions.
  * qmlplugindumper: do not pop up a window if
    an assert is triggered
  * Fix assertion: ASSERT: "hasException" in file
    jsruntime/qv4engine.cpp, line 933
  * Fix QQmlDelegateModel getting out of sync
  * QQuickWindow: add some links to resetOpenGLState
  * Remove metaobject revisioning for QQuickScreenAttached
  * Don't dereference null pointer.
  * Flickable: Cancel interaction on interactive changes
  * Don't try to draw shader effect sources with dims < 0.
  * QQuickMouseArea: Mark override functions with Q_DECL_OVERRIDE
  * Fix interaction of garbage collector with JS objects during
    QML type instantiation
  * Do not use mark() when marking ExecutionContexts
  * Don't recreate header and footer unnecessarily
  * Clear the visibleImgTags list when setting up the text layout
  * Improve programmatic flicking of ListView (and Flickable).
  * V4: work around a bug in libc++'s std::vector<bool>
  * QQmlComponent::create(): visual items must have
    a visual parent
  * Clean up the textures when deleting the content
  * Schedule layout changes to avoid refill() recursion.
  * Add autotest for incorrect steal of flick.
  * Do not crash AtlasTexture if image is null
  * Fix Node object leak in QQuickTextEditPrivate
  * shift and unshift fail for QQmlSequence types
  * Check for window != 0 in QuickTestResult::grabImage().
  * Doc: add documentation for the RSS News example
  * Fix typo in documentation
  * Binding Text width to implicitWidth can result in
    incorrect layout
  * Docs: fix "classname" indentation in the qmldir specs
  * Fix role for generic Accessible items
  * Calqlatr demo: Remove unused files
  * Remove usage of external dependencies from the RSS News demo
  * Fix crash on QQmlEngine destruction.
  * Don't dereference null QQuickWindowPrivate.
  * Add opt-out environment variable for @2x images
  * Doc: correct link/compilation errors in Qt Declarative
  * Fix crash in Flickable with pressDelay.
  * Skip rssnews demo if xmlpatterns is not present
  * Delete objects created by qmlplugindump
  * Avoid double deletion of QQuickWindow
  * Fix QQmlDelegateModel ignoring layoutChange in
    certain situations
  * Fix intermittent crash with older MinGW releases
  * Doc: Add documentation for the Maroon in Trouble example
  * Fix crash when deleting component in Component.onComplete
    through loader
  * Fix memory leak in QQmlComponent::createObject
  * Update QtQuick import value to 2.3
  * Set locked state while locking for grab.
  * QQmlObjectCreator: Clear sharedState componentAttached
    in destruction/clear
  * Initialize velocity
  * Improve RSS News Qt Quick Demo
  * Fix QQmlComponent detailed description.
  * Add a QQuickWidget - QQuickView comparison example
  * Fix crash in QObjectWrapper
- libqt5-fix-crash-with-early-QObject-property-access.patch,
  merged upstream
* Fri Aug 29 2014 mlin@suse.com
- Added upstream patch libqt5-fix-crash-with-early-QObject-property-access.patch
  * Fix crash with early QObject property access, QTBUG-40018
* Tue Aug  5 2014 hrvoje.senjan@gmail.com
- Create tools subpackage
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.1
  * Bugfix release, for more details please see:
    http://blog.qt.digia.com/blog/2014/06/25/qt-5-3-1-released/
- Added pkgconfig(Qt5Xml) BuildRequires
* Mon Jun  2 2014 hrvoje.senjan@gmail.com
- Added baselibs.conf
- Make private headers noarch
* Mon May 19 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 final
  * Minor bugfixes over previous RC
* Thu May  8 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 RC
  * For more details, please see
  http://blog.qt.digia.com/blog/2014/05/08/qt-5-3-release-candidate-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Tue May  6 2014 hrvoje.senjan@gmail.com
- Explicitly BuildRequire python-base
* Tue Mar 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 beta
  * New feature release, please see
  http://blog.qt.digia.com/blog/2014/03/25/qt-5-3-beta-released/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
- Added libQt5Widgets-private-headers-devel BuildRequires: they are
  now needed for building QQuickWidgets
- Droped aarch64-support.patch, merged upstream
* Fri Mar 21 2014 hrvoje.senjan@gmail.com
- Build, and add examples subpackage
* Mon Feb 10 2014 mlin@suse.com
- Add License files to %%doc
* Wed Feb  5 2014 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/02/05/qt-5-2-1-released/
- Remove libtool archives from packages
- Added aarch64-support.patch from upstream (merged for 5.3)
* Mon Dec 16 2013 hrvoje.senjan@gmail.com
- Make devel packages naming consistent:
  use libqt5-$upstreammodulename-(devel, private-headers-devel)
* Thu Dec 12 2013 hrvoje.senjan@gmail.com
- Update to 5.2.0 final:
  * For more details please see:
    http://blog.qt.digia.com/blog/2013/12/12/qt-5-2-released-the-best-qt-yet/
    http://qt-project.org/qt5/qt52
    http://qt.digia.com/Product/Whats-New/Qt-52/
* Fri Nov 29 2013 hrvoje.senjan@gmail.com
- Update to 5.2 rc1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/11/29/qt-5-2-release-candidate-1-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
* Wed Oct 23 2013 hrvoje.senjan@gmail.com
- Update to 5.2 beta1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/10/23/qt-5-2-beta-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
* Thu Aug 29 2013 hrvoje.senjan@gmail.com
- Update to version 5.1.1:
  * Bugfix release, please see
  http://blog.qt.digia.com/blog/2013/08/28/qt-5-1-1-released/
  http://qt.gitorious.org/qt/qtdeclarative/blobs/release/dist/changes-5.1.1
  and http://qt-project.org/wiki/Qt511KnownIssues for known issues
- Small spec cleanup
* Sat Aug  3 2013 tittiatcoke@gmail.com
- Rename packages according to Factory standards
* Sun Jul  7 2013 stephan.binner@basyskom.com
- update to Qt 5.1 release
* Tue Jun 18 2013 stephan.binner@basyskom.com
- update to Qt 5.1 RC 1
* Mon May 20 2013 stephan.binner@basyskom.com
- update to Qt 5.1 Beta 1
* Tue Apr  9 2013 stephan.binner@basyskom.com
- update to Qt 5.1 Alpha 1
* Wed Jan 30 2013 stephan.binner@basyskom.com
- update to Qt 5.0.1
* Wed Dec 19 2012 stephan.binner@basyskom.com
- update to Qt 5.0 release
* Thu Dec 13 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Release Candidate 2
* Thu Dec  6 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Release Candidate 1
* Thu Nov 15 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Beta 2
* Thu Aug 30 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Beta 1 release
* Thu May 24 2012 stephan.binner@basyskom.com
- update to newer Alpha snapshot / Beta candidate
* Fri Apr 13 2012 stephan.binner@basyskom.com
- rework package splitting for Qt 5 modularization
* Thu Apr  5 2012 dmueller@suse.com
- Initial packaging (Qt 5.0 Alpha)
